"""app URL Configuration

The `urlpatterns` list routes URLs to views. For more information please see:
    https://docs.djangoproject.com/en/4.0/topics/http/urls/
Examples:
Function views
    1. Add an import:  from my_app import views
    2. Add a URL to urlpatterns:  path('', views.home, name='home')
Class-based views
    1. Add an import:  from other_app.views import Home
    2. Add a URL to urlpatterns:  path('', Home.as_view(), name='home')
Including another URLconf
    1. Import the include() function: from django.urls import include, path
    2. Add a URL to urlpatterns:  path('blog/', include('blog.urls'))
"""
from django.conf import settings
from django.conf.urls.static import static
from django.contrib import admin
from django.urls import include, path
from django.views.generic import TemplateView

from core.views import base, demo
from core.views.callbacks import Callback

urlpatterns = [
    path("__debug__/", include("debug_toolbar.urls")),
    path("", base.Home.as_view(), name="home"),
    path("callback", Callback.as_view(), name="callback"),
    path("billing/", base.Billing.as_view(), name="billing"),
    path("order/<str:plan_name>/", base.Order.as_view(), name="order"),
    path(
        "cancel_subscription/<str:plan_name>/",
        base.Cancel.as_view(),
        name="cancel_subscription",
    ),
    path(
        "success/", TemplateView.as_view(template_name="success.html"), name="success"
    ),
    path("cancel/", TemplateView.as_view(template_name="cancel.html"), name="cancel"),
    path("portal", base.Portal.as_view(), name="portal"),
    path("admin/", admin.site.urls),
    path("accounts/", include("django.contrib.auth.urls")),
    path("accounts/signup/", base.Signup.as_view(), name="signup"),
    path("demo/modal/", demo.DemoModal.as_view(), name="modal"),
    path("demo/widget/", demo.DemoWidget.as_view(), name="widget"),
    path("demo/window/", demo.DemoWindow.as_view(), name="window"),

] + static(settings.STATIC_URL, document_root=settings.STATIC_ROOT)
